==> apache-ignite-2.13.0-src.zip: apache-ignite-2.13.0-src/modules/control-utility/src/main/java/org/apache/ignite/internal/commandline/systemview/SystemViewCommandArg.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.commandline.systemview;

import org.apache.ignite.internal.commandline.argument.CommandArg;

/** Represents all possible arguments for {@link SystemViewCommand}. */
public enum SystemViewCommandArg implements CommandArg {
    /** Id of the node to get the system view from. */
    NODE_ID("--node-id");

    /** Name of the argument. */
    private final String name;

    /** @param name Name of the argument. */
    SystemViewCommandArg(String name) {
        this.name = name;
    }

    /** {@inheritDoc} */
    @Override public String argName() {
        return name;
    }

    /** {@inheritDoc} */
    @Override public String toString() {
        return name;
    }
}

==> apache-ignite-2.15.0-src.zip: apache-ignite-2.15.0-src/modules/control-utility/src/main/java/org/apache/ignite/internal/commandline/systemview/SystemViewCommandArg.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.commandline.systemview;

import org.apache.ignite.internal.commandline.argument.CommandArg;

/** Represents all possible arguments for {@link SystemViewCommand}. */
public enum SystemViewCommandArg implements CommandArg {
    /**
     * Id of the node to get the system view from.
     *
     * @deprecated Use {@link SystemViewCommandArg#NODE_IDS} instead.
     */
    @Deprecated
    NODE_ID("--node-id"),

    /** Node IDs to get the system view from. */
    NODE_IDS("--node-ids"),

    /** Get the system view from all nodes. */
    ALL_NODES("--all-nodes");

    /** Name of the argument. */
    private final String name;

    /** @param name Name of the argument. */
    SystemViewCommandArg(String name) {
        this.name = name;
    }

    /** {@inheritDoc} */
    @Override public String argName() {
        return name;
    }

    /** {@inheritDoc} */
    @Override public String toString() {
        return name;
    }
}
